@@ -2,13 +2,13 @@
 ## NOTE: each VNIR spectra record is 6.6kb of data (compressed, gzip, level 5)
 
 # this loads and packages the data into a list of objects
-fetchRaCA <- function(series=NULL, bbox=NULL, state=NULL, get.vnir=FALSE) {
+fetchRaCA <- function(series=NULL, bbox=NULL, state=NULL, rcasiteid=NULL, get.vnir=FALSE) {
   
   # important: change the default behavior of data.frame
   opt.original <- options(stringsAsFactors = FALSE)
   
   # sanity-check: user must supply some kind of criteria
-  if(missing(series) & missing(state) & missing(bbox))
+  if(missing(series) & missing(state) & missing(bbox) & missing(rcasiteid))
     stop('you must provide some filtering criteria', call.=FALSE)
   
   # sanity-check: cannot request VNIR by state
@@ -42,6 +42,10 @@ fetchRaCA <- function(series=NULL, bbox=NULL, state=NULL, get.vnir=FALSE) {
     f <- c(f, paste('&state=', state, sep=''))
   }
   
+  if(!missing(rcasiteid)) {
+    f <- c(f, paste('&rcasiteid=', rcasiteid, sep=''))
+  }
+  
   # combine filters
   f <- paste(f, collapse='')
   
@@ -78,9 +82,9 @@ fetchRaCA <- function(series=NULL, bbox=NULL, state=NULL, get.vnir=FALSE) {
   try(veg <- read.table(gzfile(tf.veg), header=TRUE, sep='|', quote='', comment.char=''), silent=TRUE)
   
   ### 2014-01-16: data need to be re-generated, offline for now:
-  message('Carbon concentration and stock values are currently being re-estimated and are unavailable. Sorry.')
-#   try(stock <- read.table(gzfile(tf.stock), header=TRUE, sep='|', quote='', comment.char=''), silent=TRUE)
-#   try(sample <- read.table(gzfile(tf.sample), header=TRUE, sep='|', quote='', comment.char=''), silent=TRUE)
+  message('Carbon concentration and stock values are probably wrong, or at least suspect. USE WITH CAUTION.')
+  try(stock <- read.table(gzfile(tf.stock), header=TRUE, sep='|', quote='', comment.char=''), silent=TRUE)
+  try(sample <- read.table(gzfile(tf.sample), header=TRUE, sep='|', quote='', comment.char=''), silent=TRUE)
   
   # optionally load spectra
   if(get.vnir) {
